@@ -4,7 +4,7 @@ use parent qw(Perinci::CmdLine::I18N Perinci::To::Text::I18N::en);
 use Locale::Maketext::Lexicon::Gettext;
 our %Lexicon = %{ Locale::Maketext::Lexicon::Gettext->parse(<DATA>) };
 
-our $VERSION = '0.49'; # VERSION
+our $VERSION = '0.50'; # VERSION
 
 #use Data::Dump; dd \%Lexicon;
 
@@ -20,7 +20,7 @@ Perinci::CmdLine::I18N::en - English translation for Perinci::CmdLine
 
 =head1 VERSION
 
-version 0.49
+version 0.50
 
 =head1 AUTHOR
 
@@ -115,6 +115,13 @@ msgstr ""
 "    --history       List actions history\n"
 "    --clear-history Clear actions history\n"
 
+msgid  "Special options"
+msgstr "Special options"
+
+# --dry-run
+msgid  "Run in simulation mode (can also be set via environment DRY_RUN=1)"
+msgstr "Run in simulation mode (can also be set via environment DRY_RUN=1)"
+
 msgid  "Show version"
 msgstr "Show version"
 
